@@ -1,6 +1,6 @@
 // ========================================================================
 // gnubiff -- a mail notification program
-// Copyright (c) 2000-2005 Nicolas Rougier
+// Copyright (c) 2000-2006 Nicolas Rougier, 2004-2006 Robert Sowada
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License as
@@ -19,9 +19,9 @@
 // ========================================================================
 //
 // File          : $RCSfile: biff.h,v $
-// Revision      : $Revision: 1.18 $
-// Revision date : $Date: 2005/03/10 17:48:22 $
-// Author(s)     : Nicolas Rougier
+// Revision      : $Revision: 1.28 $
+// Revision date : $Date: 2006/01/07 22:35:22 $
+// Author(s)     : Nicolas Rougier, Robert Sowada
 // Short         : 
 //
 // This file is part of gnubiff.
@@ -52,65 +52,76 @@
 class Biff : public Gnubiff_Options {
 
 public:
-	// ================================================================================
+	// ========================================================================
 	//  general
-	// ================================================================================
-	std::string		passtable_;					// encryption table
+	// ========================================================================
+
 
 protected:
-	// ================================================================================
+	// ========================================================================
 	//  internal
-	// ================================================================================
-	std::vector<class Mailbox *>	mailbox_;		// mailboxes
-	GMutex *						mutex_;			// access mutex
-	class Authentication			*ui_auth_;		// ui to get username & password
-	GMutex							*ui_auth_mutex_;// Lock to avoid conflicts
-	class Preferences	*			preferences_;	// preferences ui
-	class Popup *					popup_;			// popup ui
-	class Applet *					applet_;		// applet ui
+	// ========================================================================
+	// All mailboxes that are being monitored
+	std::vector<class Mailbox *>	mailbox_;
+	/**
+	 *  Access mutex. This mutex has to be locked for working with the
+	 *  mailboxes.
+	 */
+	GMutex *						mutex_;
+	/// Mutex for obtaining passwords
+	GMutex							*auth_mutex_;
+	/// Applet user interface
+	class Applet *					applet_;
 	/// Buffer for temporary saving values when loading the config file
 	std::map<std::string,std::string> buffer_load_;
 
 public:
-	// ================================================================================
+	// ========================================================================
 	//  base
-	// ================================================================================
-	Biff (guint ui_mode = GTK_MODE,
-		  std::string filename = "");
+	// ========================================================================
+	Biff (guint ui_mode = MODE_GTK, std::string filename = "");
 	~Biff (void);
 
-	// ================================================================================
+	// ========================================================================
 	//  access
-	// ================================================================================
-	guint size (void);
-	gboolean find_mail (std::string mailid, Header &mail);
+	// ========================================================================
+	gboolean find_message (std::string mailid, Header &mail);
 	class Mailbox * mailbox (guint index);
 	class Mailbox * get (guint uin);
-	class Preferences *preferences (void)		{return preferences_;}
 	class Applet *applet (void)					{return applet_;}
-	class Popup *popup (void)					{return popup_;}
-	
 
-	// ================================================================================
-	//  main
-	// ================================================================================
-	void add (Mailbox *mailbox);					// add a new mailbox
-	Mailbox *replace (Mailbox *from, Mailbox *to);	// replace a mailbox (from) with another (to)
-	void remove (Mailbox *mailbox);					// remove a mailbox
-	gboolean password (Mailbox *mailbox);		// try to find a password for this mailbox
+	// ========================================================================
+	//  main -- mailbox handling
+	// ========================================================================
+	void add_mailbox (Mailbox *mailbox);
+	guint get_number_of_mailboxes (void);
+	std::vector<Header *> get_message_headers (gboolean use_max_num = false,
+											   guint max_num = 0);
+	gboolean get_number_of_unread_messages (guint &num);
+	gboolean get_password_for_mailbox (Mailbox *mailbox);
+	void mark_messages_as_read (void);
+	void messages_displayed (void);
+	void remove_mailbox (Mailbox *mailbox);
+	Mailbox *replace_mailbox (Mailbox *from, Mailbox *to);
+	void start_monitoring (guint delay = 0);
+	void stop_monitoring (void);
+
+	// ========================================================================
+	//  options
+	// ========================================================================
 	void option_changed (Option *option);
 	void option_update (Option *option);
+	void upgrade_options (void);
 
-	// ================================================================================
+	// ========================================================================
 	//  i/o
-	// ================================================================================
+	// ========================================================================
 	gboolean load (void);
 protected:
 	std::vector<const gchar *> save_blocks;
 	std::stringstream save_file;
 	void save_newblock (const gchar *name);
 	void save_endblock (void);
-	void upgrade_options (void);
 public:
 	void save_parameters (std::map<std::string,std::string> &map,
 						  std::string block = std::string(""));
