@@ -1,6 +1,6 @@
 // ========================================================================
 // gnubiff -- a mail notification program
-// Copyright (c) 2000-2005 Nicolas Rougier
+// Copyright (c) 2000-2006 Nicolas Rougier, 2004-2006 Robert Sowada
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License as
@@ -19,9 +19,9 @@
 // ========================================================================
 //
 // File          : $RCSfile: gnubiff.cc,v $
-// Revision      : $Revision: 1.13 $
-// Revision date : $Date: 2005/03/31 16:05:18 $
-// Author(s)     : Nicolas Rougier
+// Revision      : $Revision: 1.26 $
+// Revision date : $Date: 2006/05/07 22:07:53 $
+// Author(s)     : Nicolas Rougier, Robert Sowada
 // Short         : 
 //
 // This file is part of gnubiff.
@@ -35,25 +35,18 @@
 #include <popt.h>
 
 #ifdef USE_GNOME
-#  include <gnome.h>
-#  include <panel-applet.h>
+#	include <gnome.h>
+#	include <panel-applet.h>
+#	include "ui-applet-gnome.h"
 #endif
 
 #include "biff.h"
-#include "ui-preferences.h"
-#include "ui-applet.h"
-
-
-
-#include "biff.h"
-#include "ui-preferences.h"
-#include "ui-applet.h"
 #include "nls.h"
-
-
+#include "ui-preferences.h"
+#include "ui-applet.h"
+#include "ui-applet-gtk.h"
 
 int main (int argc, char **argv);
-int mainGTK (int argc, char **argv);
 int mainGNOME (int argc, char **argv);
 
 
@@ -78,17 +71,18 @@ int main (int argc, char **argv) {
  	for (gint i=0; i<argc; i++)
 		if (std::string(argv[i]).find("--oaf-ior-fd")==0)
 			return mainGNOME (argc, argv);
- 	return mainGTK (argc, argv);
-#else
-	return mainGTK (argc, argv);
-#endif  
-}
+#endif
 
-int mainGTK (int argc, char **argv) {
+	//
+	// Parse Options
+	//
+	GMainLoop*  gmainloop = NULL;
 	poptContext poptcon;
+	guint ui_mode = MODE_GTK;
 	int status;
 	char *config_file = 0;
-	int no_configure = false, print_version=false;
+	int no_configure = false, print_version = false, no_gui = false;
+	int systemtray = false;
 #if defined DEBUG && defined USE_GNOME
 	int debug_applet=false;
 
@@ -99,18 +93,20 @@ int mainGTK (int argc, char **argv) {
 		POPT_TABLEEND
 	};
 #endif
-
 	static struct poptOption options_general[] =
 	{
 	   	{"config",      'c' , POPT_ARG_STRING, &config_file,   0,
 		 N_("Configuration file to use"),  N_("file")},
 		{"noconfigure", 'n' , POPT_ARG_NONE,   &no_configure,  0,
 		 N_("Skip the configuration process"), NULL},
+		{"nogui",		'\0', POPT_ARG_NONE,   &no_gui,		   0,
+		 N_("Start gnubiff without GUI"), NULL},
+		{"systemtray",	'\0', POPT_ARG_NONE,   &systemtray,	   0,
+		 N_("Put gnubiff's icon into the system tray"), NULL},
 		{"version",     'v' , POPT_ARG_NONE,   &print_version, 0,
 		 N_("Print version information and exit"), NULL},
 		POPT_TABLEEND
 	};
-
 	static struct poptOption options[] =
 	{
 	   	{NULL, '\0', POPT_ARG_INCLUDE_TABLE, &options_general, 0,
@@ -124,7 +120,8 @@ int mainGTK (int argc, char **argv) {
 	};
 
 	// Parse command line
-	poptcon = poptGetContext ("gnubiff", argc,  (const char **) argv, options, 0);
+	poptcon = poptGetContext ("gnubiff", argc,  (const char **) argv,
+							  options, 0);
 	while ((status = poptGetNextOpt(poptcon)) >= 0);
 	if (status < -1) {
 		fprintf (stderr, "%s: %s\n\n",
@@ -135,13 +132,24 @@ int mainGTK (int argc, char **argv) {
 	}
 	poptGetNextOpt(poptcon);
 
+	// Decide which frontend to use
+	if (no_gui) {
+		ui_mode = MODE_NOGUI;
+		no_configure = true;
+	}
+	if (systemtray)
+		ui_mode = MODE_SYSTEMTRAY;
+
 #if defined DEBUG && defined USE_GNOME
 	if (debug_applet)
-		return mainGNOME(argc,argv);
+		return mainGNOME (argc, argv);
 #endif
 	
-	// GTK initialisation
-	gtk_init (&argc, &argv);
+	// Initialization of Glib and (if needed) GTK
+	if (no_gui)
+		gmainloop = g_main_loop_new (NULL, true);
+	else
+		gtk_init (&argc, &argv);
 
 	// Print version information if requested and exit
 	if (print_version) {
@@ -156,44 +164,30 @@ int mainGTK (int argc, char **argv) {
 	// Create biff with configuration file (or not)
 	Biff *biff;
 	if (config_file)
-		biff = new Biff(GTK_MODE, config_file);
+		biff = new Biff (ui_mode, config_file);
 	else
-		biff = new Biff(GTK_MODE);
+		biff = new Biff (ui_mode);
 
-	// Show setup panel or start gnubiff directly
-	if (no_configure) {
-		biff->applet()->update(true);
-		biff->applet()->show();
-		if (biff->value_uint ("check_mode") == AUTOMATIC_CHECK)
-			biff->applet()->start (3);
+	// Decide whether the preferences dialog shall be shown now
+	no_configure = no_configure || !biff->value_bool ("startup_preferences");
+
+	// Start applet
+	biff->applet()->start (!no_configure);
+
+	// Main loop
+	if (no_gui)
+		g_main_loop_run (gmainloop);
+	else {
+		gdk_threads_enter();
+		gtk_main();
+		gdk_threads_leave();
 	}
-	else
-		biff->preferences()->show();
-
-	// GTK main loop
-	gdk_threads_enter();
-	gtk_main();
-	gdk_threads_leave();
 
 	// Exit
 	return 0;
 }
 
 #ifdef USE_GNOME
-static gboolean gnubiff_applet_factory (PanelApplet *applet, const gchar *iid,
-										gpointer data)
-{
-	if (!strcmp (iid, "OAFIID:GNOME_gnubiffApplet")) {
-		Biff *biff = new Biff (GNOME_MODE);
-		biff->applet()->dock ((GtkWidget *) applet);
-		biff->preferences()->synchronize();
-		biff->applet()->show ();
-		biff->applet()->update (true);
-		if (biff->value_uint ("check_mode") == AUTOMATIC_CHECK)
-			biff->applet()->start (3);
-	}
-	return TRUE;
-}
 
 int mainGNOME (int argc, char **argv) {
 #if defined(PREFIX) && defined(SYSCONFDIR) && defined(DATADIR) && defined(LIBDIR)
@@ -205,7 +199,8 @@ int mainGNOME (int argc, char **argv) {
 #endif
 
 	panel_applet_factory_main ("OAFIID:GNOME_gnubiffApplet_Factory",
-							   PANEL_TYPE_APPLET, gnubiff_applet_factory, 0);
+							   PANEL_TYPE_APPLET,
+							   AppletGnome::gnubiff_applet_factory, 0);
 
 	return 0;
 }
