@@ -1,6 +1,6 @@
 // ========================================================================
 // gnubiff -- a mail notification program
-// Copyright (c) 2000-2006 Nicolas Rougier, 2004-2006 Robert Sowada
+// Copyright (c) 2000-2007 Nicolas Rougier, 2004-2007 Robert Sowada
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License as
@@ -19,8 +19,8 @@
 // ========================================================================
 //
 // File          : $RCSfile: gnubiff_options.cc,v $
-// Revision      : $Revision: 1.50 $
-// Revision date : $Date: 2006/07/23 18:56:30 $
+// Revision      : $Revision: 1.51.2.2 $
+// Revision date : $Date: 2007/05/06 16:53:43 $
 // Author(s)     : Robert Sowada, Nicolas Rougier
 // Short         : Options for gnubiff
 //
@@ -87,6 +87,10 @@ Gnubiff_Options::add_options_applet (gboolean deprecated)
 		"Shall the gnubiff applet window have window manager decoration?",
 								 false, OPTFLG_NONE, OPTGUI_TOGGLE,
 								 "applet_decoration_check"));
+	// APPLET_TASKBAR
+	add_option (new Option_Bool ("applet_taskbar", OPTGRP_POPUP,
+		"Shall the gnubiff applet window appear in the taskbar?",
+								 true));
 	// APPLET_BE_STICKY
 	add_option (new Option_Bool ("applet_be_sticky", OPTGRP_APPLET,
 		"Shall the gnubiff applet window be sticky (i.e. appear on all "
@@ -298,7 +302,7 @@ Gnubiff_Options::add_options_general (gboolean deprecated)
 		"FOLDER\\ INTERNAL\\ DATA",
 								   OPTFLG_CHANGE | OPTFLG_STRINGLIST));
 	// FILTER_GLOBAL_LAST
-	add_option (new Option_String ("filter_global_first", OPTGRP_GENERAL,
+	add_option (new Option_String ("filter_global_last", OPTGRP_GENERAL,
 		"Space separated list of regular expressions (as defined in "
 		"POSIX 1003.2) used for filtering the header lines of obtained "
         "messages in each mailbox. The regular expressions are processed in "
@@ -315,19 +319,24 @@ Gnubiff_Options::add_options_general (gboolean deprecated)
 	// SIGNAL_SIGUSR1
 	const static guint i7[] = {SIGNAL_NONE, SIGNAL_MARK_AS_READ, SIGNAL_START,
 							   SIGNAL_STOP, SIGNAL_POPUP_ENABLE,
-							   SIGNAL_POPUP_DISABLE, SIGNAL_POPUP_TOGGLE, 0};
+							   SIGNAL_POPUP_DISABLE, SIGNAL_POPUP_TOGGLE,
+							   SIGNAL_POPUP_SHOW, SIGNAL_POPUP_HIDE,
+							   SIGNAL_POPUP_TOGGLEVISIBLE, 0};
 	const static gchar *s7[] = {"none", "mark_as_read", "start", "stop",
 								"popup_enable", "popup_disable",
-								"popup_toggle", NULL};
+								"popup_toggle",	"popup_show", "popup_hide",
+								"popup_togglevisible", NULL};
 	add_option (new Option_UInt ("signal_sigusr1", OPTGRP_GENERAL,
 		"Action to be executed if the signal SIGUSR1 is caught by gnubiff. "
 		"\nPossible actions are ignoring the signal (\"none\"), marking all "
 		"messages as read (\"mark_as_read\"), starting monitoring "
 		"(\"start\"), stopping monitoring (\"stop\"), enabling and disabling "
-        "the popup (\"popup_enable\" and \"popup_disable\") or "
-		"toggling the popup status (\"popup_toggle\").",
+        "the popup (\"popup_enable\" and \"popup_disable\"), "
+		"toggling the popup enabled status (\"popup_toggle\"), showing and "
+		"hiding the popup (\"popup_show\" and \"popup_hide\"), or toggling "
+		"the popup's visibility (\"popup_togglevisible\")",
 								 SIGNAL_MARK_AS_READ,
-								 OPTFLG_ID_INT_STRICT, i7,s7));
+								 OPTFLG_ID_INT_STRICT, i7, s7));
 	// SIGNAL_SIGUSR2
 	add_option (new Option_UInt ("signal_sigusr2", OPTGRP_GENERAL,
 		"Action to be executed if the signal SIGUSR2 is caught by gnubiff. "
@@ -625,6 +634,10 @@ Gnubiff_Options::add_options_popup (gboolean deprecated)
 		"Shall the gnubiff popup window have window manager decoration?",
 								 false, OPTFLG_NONE, OPTGUI_TOGGLE,
 								 "popup_decoration_check"));
+	// POPUP_TASKBAR
+	add_option (new Option_Bool ("popup_taskbar", OPTGRP_POPUP,
+		"Shall the gnubiff popup window appear in the taskbar?",
+								 false));
 	// POPUP_BE_STICKY
 	add_option (new Option_Bool ("popup_be_sticky", OPTGRP_POPUP,
 		"Shall the gnubiff popup window be sticky (i.e. appear on all "
