@@ -1,6 +1,6 @@
 // ========================================================================
 // gnubiff -- a mail notification program
-// Copyright (c) 2000-2005 Nicolas Rougier
+// Copyright (c) 2000-2006 Nicolas Rougier, 2004-2006 Robert Sowada
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License as
@@ -19,9 +19,9 @@
 // ========================================================================
 //
 // File          : $RCSfile: imap4.cc,v $
-// Revision      : $Revision: 1.127 $
-// Revision date : $Date: 2005/04/11 21:55:00 $
-// Author(s)     : Nicolas Rougier
+// Revision      : $Revision: 1.131 $
+// Revision date : $Date: 2006/02/03 22:41:20 $
+// Author(s)     : Nicolas Rougier, Robert Sowada
 // Short         : 
 //
 // This file is part of gnubiff.
@@ -40,7 +40,6 @@
 
 #include "ui-authentication.h"
 #include "ui-applet.h"
-#include "ui-popup.h"
 #include "imap4.h"
 #include "nls.h"
 
@@ -130,11 +129,8 @@ Imap4::start (void)
 #if DEBUG
 		g_warning ("[%d] Imap exception: %s", uin(), err.what());
 #endif
-		if (err.is_mailboxerror()) {
-			status (MAILBOX_ERROR);
-			unread_.clear ();
-			seen_.clear ();
-		}
+		if (err.is_mailboxerror())
+			set_status_mailbox_error ();
 		socket_->close ();
 
 		idled_ = false;
@@ -169,7 +165,7 @@ void
 Imap4::fetch (void) throw (imap_err)
 {
 	// Is there a password? Can we obtain it?
-	if (!biff_->password(this)) throw imap_nologin_err();
+	if (!biff_->get_password_for_mailbox (this)) throw imap_nologin_err();
 
 	// Connection and authentification
 	connect();
@@ -190,15 +186,11 @@ Imap4::fetch (void) throw (imap_err)
  * includes new or removed mail, for a new mail count.
  */
 void 
-Imap4::update_applet(void)
+Imap4::update_applet (void)
 {
-	// Removed the below so notifications will queue up, instead
-	// of potential notifications being missed.
-	// if (!GTK_WIDGET_VISIBLE (biff_->popup()->get())) {
-		gdk_threads_enter();
-		biff_->applet()->update();
-		gdk_threads_leave();
-	// }
+	gdk_threads_enter();
+	biff_->applet()->update();
+	gdk_threads_leave();
 }
 
 /**
