@@ -1,6 +1,6 @@
 // ========================================================================
 // gnubiff -- a mail notification program
-// Copyright (c) 2000-2006 Nicolas Rougier, 2004-2006 Robert Sowada
+// Copyright (c) 2000-2007 Nicolas Rougier, 2004-2007 Robert Sowada
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License as
@@ -19,8 +19,8 @@
 // ========================================================================
 //
 // File          : $RCSfile: ui-applet.h,v $
-// Revision      : $Revision: 1.24 $
-// Revision date : $Date: 2006/03/12 21:10:29 $
+// Revision      : $Revision: 1.24.2.2 $
+// Revision date : $Date: 2007/04/26 22:17:24 $
 // Author(s)     : Nicolas Rougier, Robert Sowada
 // Short         : 
 //
@@ -64,11 +64,11 @@ public:
 
 	/// @see AppletGUI::mailbox_to_be_replaced ()
 	virtual void mailbox_to_be_replaced (class Mailbox *from,
-										 class Mailbox *to) {};
+										 class Mailbox *to) {}
 	/// @see AppletGUI::get_password_for_mailbox ()
-	virtual void get_password_for_mailbox (class Mailbox *mb) {};
+	virtual void get_password_for_mailbox (class Mailbox *mb) {}
 	virtual gboolean can_monitor_mailboxes (void);
-	virtual void enable_popup (gboolean enable);
+	virtual class AppletGUI *appletgui_ptr (void);
 };
 
 #endif
