@@ -1,6 +1,6 @@
 // ========================================================================
 // gnubiff -- a mail notification program
-// Copyright (c) 2000-2006 Nicolas Rougier, 2004-2006 Robert Sowada
+// Copyright (c) 2000-2007 Nicolas Rougier, 2004-2007 Robert Sowada
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License as
@@ -19,8 +19,8 @@
 // ========================================================================
 //
 // File          : $RCSfile: ui-popup.cc,v $
-// Revision      : $Revision: 1.39 $
-// Revision date : $Date: 2006/07/30 19:15:54 $
+// Revision      : $Revision: 1.39.2.3 $
+// Revision date : $Date: 2007/05/06 16:53:43 $
 // Author(s)     : Nicolas Rougier, Robert Sowada
 // Short         : 
 //
@@ -126,6 +126,28 @@ Popup::~Popup (void)
 	g_mutex_lock (timer_mutex_);
 	g_mutex_unlock (timer_mutex_);
 	g_mutex_free (timer_mutex_);
+
+	// Free allocated memory
+	free_stored_strings ();
+}
+
+/**
+ *  Free all strings that have been stored for displaying the popup.
+ */
+void 
+Popup::free_stored_strings (void)
+{
+	GtkListStore *store;
+
+	// Get tree store and clear it
+	store = GTK_LIST_STORE (gtk_tree_view_get_model (GTK_TREE_VIEW (get ("treeview"))));
+	if (store)
+		gtk_list_store_clear (store);
+
+	// Free memory of strings displayed in popup previously
+	for (guint i=0; i<stored_strings_.size(); i++)
+		g_free (stored_strings_[i]);
+	stored_strings_.clear();
 }
 
 gint
@@ -226,28 +248,22 @@ Popup::create (gpointer callbackdata)
 
 
 /** 
- * Update popup list.
- *   Be careful that we're responsible for freeing memory of updated
- *   field within tree store. Easy solution is to collect every (gchar
- *   *) used in tree store and to free them next time we enter this
- *   function (saved_strings).
+ * Update popup's list of messages and create the widgets necassary
+ * for showing the popup.
+ *
+ * @return number of headers shown in the popup
  **/
-void
+guint 
 Popup::update (void)
 {
 	GtkListStore *store;
 	GtkTreeIter iter;
-	static std::vector <gchar *> saved_strings;
   
-	// Get tree store and clear it
-	store = GTK_LIST_STORE (gtk_tree_view_get_model (GTK_TREE_VIEW ((get("treeview")))));
-	gtk_list_store_clear (store);
+	// Free stored strings and gtk list store
+	free_stored_strings ();
 
-	// Free memory of previous strings displayed in popup
-	for (guint i=0; i<saved_strings.size(); i++)
-		g_free (saved_strings[i]);
-
-	saved_strings.clear();
+	// Get list store
+	store = GTK_LIST_STORE (gtk_tree_view_get_model (GTK_TREE_VIEW (get ("treeview"))));
 
 	// Get headers to be displayed in the popup
 	std::vector<Header *> headers;
@@ -256,7 +272,7 @@ Popup::update (void)
 
 	// Sort headers
 	gboolean mb;
-	mb=Header::sort_headers(headers,biff_->value_string ("popup_sort_by"));
+	mb = Header::sort_headers (headers, biff_->value_string ("popup_sort_by"));
 
 	// Now we populate the list
 	std::vector<Header *>::iterator h = headers.begin();
@@ -271,19 +287,21 @@ Popup::update (void)
 
 		// Subject
 		gchar *subject = utf8_strndup ((*h)->subject().c_str(), std::max<guint> (size, biff_->value_uint ("popup_size_subject")));
-		saved_strings.push_back (subject);
 
 		// Date
 		gchar *date = utf8_strndup ((*h)->date().c_str(), std::max<guint> (size, biff_->value_uint ("popup_size_date")));
-		saved_strings.push_back (date);
 
 		// Sender
 		gchar *sender = utf8_strndup ((*h)->sender().c_str(), std::max<guint> (size, biff_->value_uint ("popup_size_sender")));
-		saved_strings.push_back (sender);
 
 		// Mail identifier
 		gchar *mailid = g_strdup ((*h)->mailid().c_str());
-		saved_strings.push_back (mailid);
+
+		// The strings have to be stored as long as the popup might be shown
+		stored_strings_.push_back (subject);
+		stored_strings_.push_back (date);
+		stored_strings_.push_back (sender);
+		stored_strings_.push_back (mailid);
 
 		std::stringstream s;
 		s << (*h)->position();
@@ -332,6 +350,8 @@ Popup::update (void)
 			gtk_tree_view_column_set_visible (column, false);
 		}
 	}
+
+	return headers.size();
 }
 
 /**
@@ -376,6 +396,8 @@ Popup::show (std::string name)
 		gtk_window_unstick (dialog);
 	gtk_window_set_keep_above (dialog, biff_->value_bool ("popup_keep_above"));
 	gtk_window_set_skip_pager_hint (dialog,!biff_->value_bool ("popup_pager"));
+	gtk_window_set_skip_taskbar_hint (dialog,
+									  !biff_->value_bool ("popup_taskbar"));
 
 	g_mutex_lock (timer_mutex_);
 	if (poptag_ > 0) 
@@ -501,25 +523,31 @@ Popup::on_select (GtkTreeSelection *selection)
 		gtk_text_buffer_set_text (buffer, "", -1);
 		gtk_text_buffer_get_iter_at_offset (buffer, &iter, 0);
 
-		gchar *markup;
+		gchar *markup = NULL;
 
 		// Sender
 		markup = g_markup_printf_escaped ("<small>%s</small>",
 										  selected_header_.sender().c_str());
-		gtk_label_set_markup (GTK_LABEL(get("from")), markup);
-		g_free (markup);
+		if (markup) {
+			gtk_label_set_markup (GTK_LABEL(get("from")), markup);
+			g_free (markup);
+		}
 
 		// Subject
 		markup = g_markup_printf_escaped ("<small>%s</small>",
 										  selected_header_.subject().c_str());
-		gtk_label_set_markup (GTK_LABEL(get("subject")), markup);
-		g_free (markup);
+		if (markup) {
+			gtk_label_set_markup (GTK_LABEL(get("subject")), markup);
+			g_free (markup);
+		}
 
 		// Date
 		markup = g_markup_printf_escaped ("<small>%s</small>",
 										  selected_header_.date().c_str());
-		gtk_label_set_markup (GTK_LABEL(get("date")), markup);
-		g_free (markup);
+		if (markup) {
+			gtk_label_set_markup (GTK_LABEL(get("date")), markup);
+			g_free (markup);
+		}
 
 		// Body
 		text = charset_to_utf8 (selected_header_.body(),
