@@ -1,6 +1,6 @@
 // ========================================================================
 // gnubiff -- a mail notification program
-// Copyright (c) 2000-2005 Nicolas Rougier
+// Copyright (c) 2000-2006 Nicolas Rougier, 2004-2006 Robert Sowada
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License as
@@ -19,9 +19,9 @@
 // ========================================================================
 //
 // File          : $RCSfile: ui-properties.cc,v $
-// Revision      : $Revision: 1.20 $
-// Revision date : $Date: 2005/07/17 14:28:28 $
-// Author(s)     : Nicolas Rougier
+// Revision      : $Revision: 1.25 $
+// Revision date : $Date: 2006/01/01 16:44:53 $
+// Author(s)     : Nicolas Rougier, Robert Sowada
 // Short         : 
 //
 // This file is part of gnubiff.
@@ -108,9 +108,9 @@ Properties::~Properties (void)
 }
 
 gboolean
-Properties::create (void)
+Properties::create (gpointer callbackdata)
 {
-	gboolean result = GUI::create();
+	gboolean result = GUI::create(this);
 
 	group_ = gtk_size_group_new (GTK_SIZE_GROUP_HORIZONTAL);
 	gtk_size_group_add_widget (group_, get ("name"));
@@ -357,7 +357,7 @@ Properties::on_apply (GtkWidget *widget)
 	if (selected_type_ == TYPE_AUTODETECT) {
 		mailbox_->protocol (PROTOCOL_NONE);
 		Mailbox *mailbox = new Mailbox (*mailbox_);
-		preferences_->biff()->replace (mailbox_, mailbox);
+		preferences_->biff()->replace_mailbox (mailbox_, mailbox);
 	}
 
 	// Second case: type has been set to local
@@ -378,9 +378,9 @@ Properties::on_apply (GtkWidget *widget)
 			mailbox_->protocol (PROTOCOL_NONE);
 			// If possible create a correct mailbox, otherwise a generic one
 			// (to force lookup)
-			if (!(mailbox=Mailbox::lookup_local(*mailbox_)))
-				mailbox=new Mailbox (*mailbox_);
-			preferences_->biff()->replace (mailbox_, mailbox);
+			if (!(mailbox = Mailbox::lookup_local (*mailbox_)))
+				mailbox = new Mailbox (*mailbox_);
+			preferences_->biff()->replace_mailbox (mailbox_, mailbox);
 		}
 	}
 
@@ -390,26 +390,25 @@ Properties::on_apply (GtkWidget *widget)
 		if ((mailbox_->protocol() != PROTOCOL_IMAP4)
 			|| (mailbox_->status() == MAILBOX_UNKNOWN)) {
 			Mailbox *mailbox = new Imap4 (*mailbox_);
-			preferences_->biff()->replace (mailbox_, mailbox);
+			preferences_->biff()->replace_mailbox (mailbox_, mailbox);
 		}
 	}
 
-
 	// Fourth case: type is set to pop
 	else if (selected_type_ == TYPE_POP) {
 		if (((mailbox_->protocol() != PROTOCOL_APOP)
 			 || (mailbox_->status() == MAILBOX_UNKNOWN))
 			&& (selected_auth_ == AUTH_APOP)) {
 			Mailbox *mailbox = new Apop (*mailbox_);
-			preferences_->biff()->replace (mailbox_, mailbox);
+			preferences_->biff()->replace_mailbox (mailbox_, mailbox);
 		}
 		else if ((mailbox_->protocol() != PROTOCOL_POP3)
 				 || (mailbox_->status() == MAILBOX_UNKNOWN)) {
 			Mailbox *mailbox = new Pop3 (*mailbox_);
-			preferences_->biff()->replace (mailbox_, mailbox);
+			preferences_->biff()->replace_mailbox (mailbox_, mailbox);
 		}
 	}
-	preferences_->synchronize();
+	preferences_->synchronize ();
 }
 
 void
@@ -418,7 +417,7 @@ Properties::on_cancel (GtkWidget *widget)
 	hide ();
 	Preferences *prefs = preferences_;
 	if (prefs->added()) {
-		prefs->biff()->remove (prefs->biff()->get(prefs->added()->uin()));
+		prefs->biff()->remove_mailbox (prefs->biff()->get(prefs->added()->uin()));
 		prefs->added(0);
 		prefs->synchronize ();		
 	}
