@@ -19,9 +19,9 @@
 // ========================================================================
 //
 // File          : $RCSfile: ui-properties.h,v $
-// Revision      : $Revision: 1.4 $
-// Revision date : $Date: 2005/06/23 20:12:05 $
-// Author(s)     : Nicolas Rougier
+// Revision      : $Revision: 1.6 $
+// Revision date : $Date: 2006/01/01 16:44:53 $
+// Author(s)     : Nicolas Rougier, Robert Sowada
 // Short         : 
 //
 // This file is part of gnubiff.
@@ -67,7 +67,7 @@ public:
 	~Properties (void);
 
 	/* main */
-	gboolean create (void);
+	gboolean create (gpointer callbackdata);
 	void show (std::string name = "dialog");
 
 	// ========================================================================
